@@ -1,46 +1,12 @@
+#  License: GNU GPLv3+, Rodrigo Schwencke (Copyleft) 
+
 """
-Graphviz extension for Markdown (e.g. for mkdocs) :
-Renders the output inline, eliminating the need to configure an output
-directory.
+(Comprehensive) LaTeX Extension for Mkdocs, with custom LaTeX packages, and Dynamic Mkdocs Light and Dark Themes.
+Renders the output as Base64 SVGs.
 
-Supports outputs types of SVG and PNG. The output will be taken from the
-filename specified in the tag, if given, or. Example:
+Requires a comprehensive LaTeX distribution, like texlive-most in Manjaro/Archlinux
 
-in SVG:
-
-```dot
-digraph G {
-    rankdir=LR
-    Earth [peripheries=2]
-    Mars
-    Earth -> Mars
-}
-```
-
-```graphviz dot attack_plan.svg
-digraph G {
-    rankdir=LR
-    Earth [peripheries=2]
-    Mars
-    Earth -> Mars
-}
-```
-
-in PNG:
-
-```graphviz dot attack_plan.png
-digraph G {
-    rankdir=LR
-    Earth [peripheries=2]
-    Mars
-    Earth -> Mars
-}
-```
-
-Requires the graphviz library (http://www.graphviz.org/) and python 3
-
-Inspired by jawher/markdown-dot (https://github.com/jawher/markdown-dot)
-Forked from  cesaremorel/markdown-inline-graphviz (https://github.com/cesaremorel/markdown-inline-graphviz)
+This extension is the exclusive work of Rodrigo Schwencke, Copyleft.
 """
 
 import os
@@ -99,7 +65,7 @@ DEFAULT_PRIORITY = '75'
 inlineMode = True
 DEFAULT_PACKAGES = ['amsmath', 'tkz-tab', 'amssymb']
 
-DEBUG = True
+DEBUG = False
 
 ESC_CHAR = {
     '$': r"\$",
@@ -128,7 +94,6 @@ class MkdocsTex2SvgPreprocessor(markdown.preprocessors.Preprocessor):
         self.formatConfigOptions()
 
     def formatConfigOptions(self):
-        print("self.config=", self.config)
         for entry in self.config.keys():
             if entry == "vartable": # format vartable options
                 colorLight = self.config[entry][0]["light"]["color"] = self.config[entry][0]["light"]["color"].lower()
@@ -151,23 +116,23 @@ class MkdocsTex2SvgPreprocessor(markdown.preprocessors.Preprocessor):
                     colorDark = self.config[entry][0]["dark"]["color"] = "#"+str(self.config[entry][0]["dark"]["color"])
 
                 # Set Background Colors for Labels
-                if bgLabelLight in HTML_COLORS.keys(): # HTML HEXA COLOR
+                if bgLabelLight in HTML_COLORS.keys(): # HTML HEXA COLOR, just for information
                     bgLabelLight = self.config[entry][0]["light"]["bglabel"]
                 elif len(self.config[entry][0]["light"]["bglabel"]) in [3, 6, 8]:
                     bgLabelLight = self.config[entry][0]["light"]["bglabel"] = "#"+str(self.config[entry][0]["light"]["bglabel"])
 
-                if bgLabelDark in HTML_COLORS.keys(): # HTML HEXA COLOR
+                if bgLabelDark in HTML_COLORS.keys(): # HTML HEXA COLOR, just for information
                     bgLabelDark = self.config[entry][0]["dark"]["bglabel"]
                 elif len(self.config[entry][0]["dark"]["bglabel"]) in [3, 6, 8]:
                     bgLabelDark = self.config[entry][0]["dark"]["bglabel"] = "#"+str(self.config[entry][0]["dark"]["bglabel"])
 
                 # Set Background Colors for Forbidden Values (FV / Valeurs Interdites / VI)
-                if bgVILight in HTML_COLORS.keys(): # HTML HEXA COLOR
+                if bgVILight in HTML_COLORS.keys(): # HTML HEXA COLOR, just for information
                     bgVILight = self.config[entry][0]["light"]["bgvi"]
                 elif len(self.config[entry][0]["light"]["bgvi"]) in [3, 6, 8]:
                     bgVILight = self.config[entry][0]["light"]["bgvi"] = "#"+str(self.config[entry][0]["light"]["bgvi"])
 
-                if bgVIDark in HTML_COLORS.keys(): # HTML HEXA COLOR
+                if bgVIDark in HTML_COLORS.keys(): # HTML HEXA COLOR, just for information
                     bgVIDark = self.config[entry][0]["dark"]["bgvi"]
                 elif len(self.config[entry][0]["dark"]["bgvi"]) in [3, 6, 8]:
                     bgVIDark = self.config[entry][0]["dark"]["bgvi"] = "#"+str(self.config[entry][0]["dark"]["bgvi"])
@@ -277,7 +242,6 @@ $$"""
                     decalage = self.get_decalage("graphviz "+command, text)
                     htmlHeader = " "*decalage+f"""<span class="tex2svg"></span>"""
                 else: # VARTABLE command
-                    # text = self.escape_chars(text)
                     filename = "noname.svg"
                     command = "vartable"
                     decalage = self.get_decalage(command, text)
@@ -298,7 +262,6 @@ $$"""
                     # Create Random Name
                     randomFilename = f"{dirPath}/tmp{salt}"
                     self.to_file(tex, f"{randomFilename}.tex")
-                    print("randomFilename=", randomFilename)
 
                     # Export Tkz-tab to Svg
                     os.system(f"pdflatex -output-directory {dirPath} {randomFilename}.tex &> /dev/null")
@@ -378,16 +341,23 @@ $$"""
 
                     # Clean The Tmp Folder after
                     if not DEBUG:
-                        os.remove(f"""{randomFilename}.tex""")
-                        os.remove(f"""{randomFilename}.aux""")
-                        os.remove(f"""{randomFilename}.log""")
-                        os.remove(f"""{randomFilename}.pdf""")
-                        os.remove(f"""{randomFilename}_crop.pdf""")
-                        os.remove(f"""{randomFilename}.svg""")
-                        if os.path.exists(f"""{randomFilename}dark.svg"""):
-                            os.remove(f"""{randomFilename}dark.svg""")
-                        if os.path.exists(f"""{randomFilename}light.svg"""):
-                            os.remove(f"""{randomFilename}light.svg""")
+                        for filename in os.listdir(dirPath):
+                            try:
+                                if os.path.exists(f"{dirPath}/{filename}"):
+                                    os.remove(f"{dirPath}/{filename}")
+                            except:
+                                print("oups..")
+                        # os.remove(f"""{randomFilename}.tex""")
+                        # os.remove(f"""{randomFilename}.aux""")
+                        # os.remove(f"""{randomFilename}.log""")
+                        # os.remove(f"""{randomFilename}.pdf""")
+                        # os.remove(f"""{randomFilename}_crop.pdf""")
+                        # os.remove(f"""{randomFilename}.svg""")
+                        # os.remove(f"{dirPath}/separator.html")
+                        # if os.path.exists(f"""{randomFilename}dark.svg"""):
+                        #     os.remove(f"""{randomFilename}dark.svg""")
+                        # if os.path.exists(f"""{randomFilename}light.svg"""):
+                        #     os.remove(f"""{randomFilename}light.svg""")
 
                     # text = '%s\n%s\n%s\n%s' % (
                     #     text[:m.start()], img1, img2, text[m.end():])
